@@ -3,7 +3,7 @@
 //  $Id$
 //
 //  Created by Jean-Etienne LAMIAUD on Fri Mar 07 2005.
-//  Copyright (c) 2005-2018. Jean-Etienne LAMIAUD
+//  Copyright (c) 2005-2020. Jean-Etienne LAMIAUD
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@
 
 #include "processing_core.h"
 #include "LynkeosFourierBuffer.h"
-#include "LynkeosStandardImageBufferAdditions.h"
+#include "LynkeosImageBufferAdditions.h"
 
 #ifndef DOUBLE_PIXELS
 #define FFTW_COMPLEX fftwf_complex
@@ -518,7 +518,10 @@ static void vect_spectrum_div_one_line(LynkeosFourierBuffer *a,
                                                              width:_w
                                                             height:_h
                                                           withGoal:_goal];
-   memcpy( buf->_data, _data, _nPlanes*sizeof(LNKCOMPLEX)*_spadw*_h );
+   // Copy line by line, as the padding may differ between original and copy
+   for (int p = 0; p < buf->_nPlanes; p++)
+      for (int y = 0; y < buf->_h; y++)
+         memcpy( buf->_planes[p] + y*buf->_padw, _planes[p] + y*_padw, sizeof(REAL)*buf->_w );
    buf->_isSpectrum = _isSpectrum;
 
    return( buf );
