@@ -47,7 +47,9 @@ static void getImageSample( REAL * const * const sample,
    NSImage* offScreenImage;
    NSBitmapImageRep* bitMap;
    u_char *plane[5];
-   u_short x, y, rowSize, pixelSize;
+   int x, y, redIndex, greenIndex, blueIndex;
+   u_short rowSize, pixelSize, bitsPerSample, sampleSize;
+   NSBitmapFormat format;
    BOOL planar;
    float color[3];
 
@@ -94,9 +96,28 @@ static void getImageSample( REAL * const * const sample,
 
    // Access the data
    [bitMap getBitmapDataPlanes:plane];
+   format = [bitMap bitmapFormat];
    rowSize = [bitMap bytesPerRow];
+   bitsPerSample = [bitMap bitsPerSample];
    pixelSize = [bitMap bitsPerPixel]/8;
-
+   if ((bitsPerSample % 8) != 0)
+   {
+      NSLog(@"Samples are not aligned on byte boundary : %d bits", bitsPerSample);
+      return;
+   }
+   sampleSize = bitsPerSample/8;
+   if ((format & NSBitmapFormatAlphaFirst) != 0)
+   {
+      redIndex = 1;
+      greenIndex = 2;
+      blueIndex = 3;
+   }
+   else
+   {
+      redIndex = 0;
+      greenIndex = 1;
+      blueIndex = 2;
+   }
    planar = [bitMap isPlanar];
 
    for ( y = 0; y < ath; y++ )
@@ -104,21 +125,60 @@ static void getImageSample( REAL * const * const sample,
       for ( x = 0; x < atw; x++ )
       {
          u_short c;
+         void *redSample, *greenSample, *blueSample;
 
          // Read the data in the bitmap
          if ( planar )
          {
-            color[RED_PLANE] = plane[0][y*rowSize+x];
-            color[GREEN_PLANE] = plane[1][y*rowSize+x];
-            color[BLUE_PLANE] = plane[2][y*rowSize+x];
+            redSample = &plane[0][y*rowSize+x*sampleSize];
+            greenSample = &plane[1][y*rowSize+x*sampleSize];
+            blueSample = &plane[2][y*rowSize+x*sampleSize];
          }
          else
          {
-            color[RED_PLANE] = plane[0][y*rowSize+x*pixelSize];
-            color[GREEN_PLANE] = plane[0][y*rowSize+x*pixelSize+1];
-            color[BLUE_PLANE] = plane[0][y*rowSize+x*pixelSize+2];
+            redSample = &plane[0][y*rowSize+x*pixelSize];
+            greenSample = &plane[0][y*rowSize+x*pixelSize+sampleSize];
+            blueSample = &plane[0][y*rowSize+x*pixelSize+2*sampleSize];
          }
 
+         switch (bitsPerSample)
+         {
+            case 8:
+               color[RED_PLANE] = (float)*(uint8_t*)redSample;
+               color[GREEN_PLANE] = (float)*(uint8_t*)greenSample;
+               color[BLUE_PLANE] = (float)*(uint8_t*)blueSample;
+               break;
+            case 16:
+               if ((format & NSBitmapFormatFloatingPointSamples))
+               {
+                  color[RED_PLANE] = 256.0*(float)*(__fp16*)redSample;
+                  color[GREEN_PLANE] = 256.0*(float)*(__fp16*)greenSample;
+                  color[BLUE_PLANE] = 256.0*(float)*(__fp16*)blueSample;
+               }
+               else
+               {
+                  color[RED_PLANE] = (float)*(uint16_t*)redSample;
+                  color[GREEN_PLANE] = (float)*(uint16_t*)greenSample;
+                  color[BLUE_PLANE] = (float)*(uint16_t*)blueSample;
+               }
+               break;
+            case 32:
+               if ((format & NSBitmapFormatFloatingPointSamples))
+               {
+                  color[RED_PLANE] = *(float*)redSample;
+                  color[GREEN_PLANE] = *(float*)greenSample;
+                  color[BLUE_PLANE] = *(float*)blueSample;
+               }
+               else
+               {
+                  color[RED_PLANE] = (float)*(uint32_t*)redSample;
+                  color[GREEN_PLANE] = (float)*(uint32_t*)greenSample;
+                  color[BLUE_PLANE] = (float)*(uint32_t*)blueSample;
+               }
+               break;
+            default:
+               break;
+         }
          // Convert to monochrome, if needed
          if ( nPlanes == 1 )
             color[0] = (color[RED_PLANE] 
