@@ -1,7 +1,7 @@
 //  $Id$
 //
 //  Created by Jean-Etienne LAMIAUD on Sun Dec 12 2005.
-//  Copyright (c) 2005-2014. Jean-Etienne LAMIAUD
+//  Copyright (c) 2005-2020. Jean-Etienne LAMIAUD
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@
 
 #include "processing_core.h"
 #include "corelation.h"
-#include "LynkeosStandardImageBufferAdditions.h"
+#include "LynkeosImageBufferAdditions.h"
 
 #include "LynkeosBasicAlignResult.h"
 
@@ -706,7 +706,7 @@ NSArray* itemAlignSquares(id <LynkeosProcessableItem> item,
 #if 0 // Debug code
          if ( !isAligned || [[(MyImageListItem*)item index] intValue] == 0)
          {
-            LynkeosStandardImageBuffer *img = nil;
+            LynkeosImageBuffer *img = nil;
             if ( !isAligned )
             {
                NSLog(@"Failed to align image %d", [[(MyImageListItem*)item index] intValue]);
