@@ -3,7 +3,7 @@
 //  $Id$
 //
 //  Created by Jean-Etienne LAMIAUD on Fri Nov 28 2003.
-//  Copyright (c) 2003-2018. Jean-Etienne LAMIAUD
+//  Copyright (c) 2003-2020. Jean-Etienne LAMIAUD
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@
 #include "MyGuiConstants.h"
 #include "MyImageListWindow.h"
 
-#include "LynkeosStandardImageBufferAdditions.h"
+#include "LynkeosImageBufferAdditions.h"
 #include "LynkeosGammaCorrecter.h"
 #include "MyUserPrefsController.h"
 
@@ -891,7 +891,7 @@ typedef enum { K_UP, K_DOWN } enumeration_direction_t;
    }
 }
 
-- (void) saveImage:(LynkeosStandardImageBuffer*)image withBlack:(double*)black
+- (void) saveImage:(LynkeosImageBuffer*)image withBlack:(double*)black
              white:(double*)white
              gamma:(double*)gamma
 {
@@ -957,7 +957,7 @@ typedef enum { K_UP, K_DOWN } enumeration_direction_t;
          [myWatchCursor push];
 
          // And save at last
-         LynkeosStandardImageBuffer *copy = [image copy];
+         LynkeosImageBuffer *copy = [image copy];
          const u_short nPlanes = copy->_nPlanes;
          u_short x, y, c;
          double vmin, vmax, a;
@@ -987,9 +987,9 @@ typedef enum { K_UP, K_DOWN } enumeration_direction_t;
          [writer saveImageAtURL:url
                        withData:(const REAL*const*const)[copy colorPlanes]
                      blackLevel:black[nPlanes] whiteLevel:white[nPlanes]
-                     withPlanes:image->_nPlanes
-                          width:image->_w lineWidth:image->_padw
-                         height:image->_h
+                     withPlanes:copy->_nPlanes
+                          width:copy->_w lineWidth:copy->_padw
+                         height:copy->_h
                        metaData:nil];
          [copy release];
 
@@ -1004,9 +1004,9 @@ typedef enum { K_UP, K_DOWN } enumeration_direction_t;
    }
 }
 
-- (LynkeosStandardImageBuffer*) loadImage
+- (LynkeosImageBuffer*) loadImage
 {
-   LynkeosStandardImageBuffer *image = nil;
+   LynkeosImageBuffer *image = nil;
    NSOpenPanel* panel = [NSOpenPanel openPanel];
    NSDictionary *fileTypes =
    [[MyPluginsController defaultPluginController] getImageReaders];
@@ -1051,7 +1051,7 @@ typedef enum { K_UP, K_DOWN } enumeration_direction_t;
             u_short w, h, n;
             [reader imageWidth:&w height:&h];
             n = [reader numberOfPlanes];
-            image = [[[LynkeosStandardImageBuffer alloc] initWithNumberOfPlanes:n
+            image = [[[LynkeosImageBuffer alloc] initWithNumberOfPlanes:n
                                                              width:w
                                                             height:h] autorelease];
             [reader getImageSample:[image colorPlanes]
@@ -1329,7 +1329,7 @@ typedef enum { K_UP, K_DOWN } enumeration_direction_t;
 - (void) saveStackedImage :(id)sender
 {
    id <LynkeosProcessableItem> item = nil;
-   LynkeosStandardImageBuffer *img;
+   LynkeosImageBuffer *img;
 
    // Get the active item
    switch ( _dataMode )
