@@ -3,7 +3,7 @@
 //  $Id$
 //
 //  Created by Jean-Etienne LAMIAUD on Wed Jun 21 2007.
-//  Copyright (c) 2007-2014. Jean-Etienne LAMIAUD
+//  Copyright (c) 2007-2022. Jean-Etienne LAMIAUD
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -315,8 +315,7 @@ static NSString * const K_STACK_NAME = @"name";
 - (void) processStarted:(NSNotification*)notif
 {
    // We are only concerned by stacking process
-   if ( [[notif userInfo] objectForKey:LynkeosUserInfoProcess]
-        == [MyImageStacker class] )
+   if ( [[notif userInfo] objectForKey:LynkeosUserInfoProcess] == [MyImageStacker class] )
    {
       // Change the button title
       [_stackButton setTitle:NSLocalizedString(@"Stop",@"Stop button")];
@@ -445,6 +444,7 @@ static NSString * const K_STACK_NAME = @"name";
               [(MyImageListItem*)[[list imageArray] objectAtIndex:0] imageSize];
       params->_transform = [[NSAffineTransform alloc] init];
       params->_monochromeStack = NO;
+      params->_normalized = NO;
       params->_stackMethod = Stacking_Standard;
       params->_stackLock = [[NSConditionLock alloc] init];
 
@@ -471,8 +471,12 @@ static NSString * const K_STACK_NAME = @"name";
    state = (params->_monochromeStack ? NSOnState : NSOffState );
    if ( [_monochromeCheckBox state] != state )
       [_monochromeCheckBox setState:state];
+   state = (params->_normalized ? NSOnState : NSOffState);
+   if ( [_normalizeCheckBox state] != state)
+      [_normalizeCheckBox setState:state];
    [_doubleSizeCheckBox setEnabled:(data == ListData && mode == ImageMode)];
    [_monochromeCheckBox setEnabled:(data == ListData && mode == FlatFieldMode)];
+   [_normalizeCheckBox setEnabled:(data == ListData && mode == ImageMode)];
 
    Stack_Mode_t s_mode = (params->_stackMethod != Stacking_Calibration
                           ? params->_stackMethod
@@ -523,6 +527,7 @@ static NSString * const K_STACK_NAME = @"name";
       [_cropH setEnabled:NO];
       [_doubleSizeCheckBox setEnabled:NO];
       [_monochromeCheckBox setEnabled:NO];
+      [_normalizeCheckBox setEnabled:NO];
       [_methodPopup setEnabled:NO];
       [_methodPane selectTabViewItemAtIndex:0];
       [_stackButton setEnabled:NO];
@@ -773,6 +778,20 @@ static NSString * const K_STACK_NAME = @"name";
                   forProcessing:myImageStackerRef];
 }
 
+- (IBAction) normalizeAction :(id)sender
+{
+   id <LynkeosImageList> list = [_document currentList];
+   MyImageStackerParameters *params =
+      [list getProcessingParameterWithRef:myImageStackerParametersRef
+                            forProcessing:myImageStackerRef];
+
+   params->_normalized = ([_normalizeCheckBox state] == NSOnState);
+
+   [list setProcessingParameter:params
+                        withRef:myImageStackerParametersRef
+                  forProcessing:myImageStackerRef];
+}
+
 - (IBAction) methodChange:(id)sender
 {
    id <LynkeosImageList> list = [_document currentList];
@@ -886,6 +905,7 @@ static NSString * const K_STACK_NAME = @"name";
       [_cropH setEnabled:NO];
       [_doubleSizeCheckBox setEnabled:NO];
       [_monochromeCheckBox setEnabled:NO];
+      [_normalizeCheckBox setEnabled:NO];
 
       // Freeze the selection rectangle
       LynkeosIntegerRect r = [_imageView getSelection];
