@@ -3,7 +3,7 @@
 //  $Id$
 //
 //  Created by Jean-Etienne LAMIAUD on Wed Sep 24 2003.
-//  Copyright (c) 2003-2018. Jean-Etienne LAMIAUD
+//  Copyright (c) 2003-2022. Jean-Etienne LAMIAUD
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -891,16 +891,20 @@ static const double MM_LN_10 = -M_LN10;
    }
    else
    {
+      if ( selRect.size.width > _canvasRect.size.width)
+         selRect.size.width  = _canvasRect.size.width;
       if ( selRect.origin.x < _canvasRect.origin.x )
          selRect.origin.x = _canvasRect.origin.x;
       else if ( selRect.origin.x + selRect.size.width
                  > _canvasRect.origin.x + _canvasRect.size.width )
-         selRect.origin.x = _canvasRect.size.width - selRect.size.width - 1;
+         selRect.origin.x = _canvasRect.size.width - selRect.size.width;
+      if ( selRect.size.height > _canvasRect.size.height)
+         selRect.size.height  = _canvasRect.size.height;
       if ( selRect.origin.y < _canvasRect.origin.y )
          selRect.origin.y = _canvasRect.origin.y;
       else if ( selRect.origin.y + selRect.size.height
                  > _canvasRect.origin.y + _canvasRect.size.height )
-         selRect.origin.y = _canvasRect.size.height - selRect.size.height - 1;
+         selRect.origin.y = _canvasRect.size.height - selRect.size.height;
    }
 
    // Check if something has changed
