@@ -3,7 +3,7 @@
 //  $Id$
 //
 //  Created by Jean-Etienne LAMIAUD on Sat Nov 3 2007.
-//  Copyright (c) 2007-2014. Jean-Etienne LAMIAUD
+//  Copyright (c) 2007-2020. Jean-Etienne LAMIAUD
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 //
 
 #include "MyDocument.h"
-#include "LynkeosStandardImageBufferAdditions.h"
+#include "LynkeosImageBufferAdditions.h"
 #include "ProcessingUtilities.h"
 #include "MyLucyRichardsonView.h"
 
@@ -46,7 +46,7 @@ static void updatePSF( MyLucyRichardsonViewParameters *params,
       return;
    }
 
-   LynkeosStandardImageBuffer *buf = nil;
+   LynkeosImageBuffer *buf = nil;
    LynkeosIntegerSize s = [item imageSize];
    LynkeosIntegerRect sel;
 
@@ -171,7 +171,7 @@ static void updatePSF( MyLucyRichardsonViewParameters *params,
  * @param psf The PSF to swap
  * @param back Whether to swap from the original image or back to it
  */
-static void swapPsf( LynkeosStandardImageBuffer *psf, BOOL back )
+static void swapPsf( LynkeosImageBuffer *psf, BOOL back )
 {
    const u_short w = psf->_w, h = psf->_h;
    REAL *buf;
@@ -824,7 +824,7 @@ NSMutableDictionary *monitorDictionary = nil;
 {
    double b[2], w[2], g[2] = {1.0,1.0};
 
-   LynkeosStandardImageBuffer *buf = [[_params->_psf copy] autorelease];
+   LynkeosImageBuffer *buf = [[_params->_psf copy] autorelease];
    // Transpose the quadrants for saving (0,0 at center)
    swapPsf(buf,YES);
    // And save
