@@ -3,7 +3,7 @@
 //  $Id$
 //
 //  Created by Jean-Etienne LAMIAUD on Sat Oct 27 2007.
-//  Copyright (c) 2007-2014. Jean-Etienne LAMIAUD
+//  Copyright (c) 2007-2020. Jean-Etienne LAMIAUD
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -760,10 +760,10 @@
       *param = nil;
 }
 
-- (void) saveImage:(LynkeosStandardImageBuffer*)image
+- (void) saveImage:(LynkeosImageBuffer*)image
          withBlack:(double*)black white:(double*)white gamma:(double*)gamma
 { [_window saveImage:image withBlack:black white:white gamma:gamma]; }
-- (LynkeosStandardImageBuffer*) loadImage
+- (LynkeosImageBuffer*) loadImage
 { return( [_window loadImage] ); }
 
 - (void)reloadItem:(id<LynkeosProcessableItem>)item { [_window reloadItem:item]; }
