@@ -3,7 +3,7 @@
 //  $Id$
 //
 //  Created by Jean-Etienne LAMIAUD on Wed Feb 5 2014.
-//  Copyright (c) 2014. Jean-Etienne LAMIAUD
+//  Copyright (c) 2014-2020. Jean-Etienne LAMIAUD
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
 #include <LynkeosCore/LynkeosProcessing.h>
 #include <LynkeosCore/LynkeosFileReader.h>
 
-#include "LynkeosStandardImageBufferAdditions.h"
+#include "LynkeosImageBufferAdditions.h"
 #include "LynkeosBasicAlignResult.h"
 #include "MyImageListItem.h"
 #include "MyDocument.h"
@@ -73,7 +73,7 @@ NSString *K_ITEM_STACKED_REF = @"ItemStackedFlag";
 // Fake reader
 @interface StackTestReader : NSObject <LynkeosImageFileReader>
 {
-   LynkeosStandardImageBuffer *_image;
+   LynkeosImageBuffer *_image;
 }
 @end
 
@@ -151,7 +151,7 @@ NSString *K_ITEM_STACKED_REF = @"ItemStackedFlag";
 - (id) init
 {
    if ( (self = [super init]) != nil )
-      _image = [[LynkeosStandardImageBuffer imageBufferWithNumberOfPlanes:1
+      _image = [[LynkeosImageBuffer imageBufferWithNumberOfPlanes:1
                                                                     width:2
                                                                    height:2]
                 retain];
@@ -379,7 +379,7 @@ NSString *K_ITEM_STACKED_REF = @"ItemStackedFlag";
       XCTAssertTrue( stackedFlag->stacked,
                     @"Bad notification flag state for item 0" );
 
-   LynkeosStandardImageBuffer *img = [[_doc imageList] getImage];
+   LynkeosImageBuffer *img = [[_doc imageList] getImage];
    XCTAssertNotNil( img, @"No stacking result for item 0" );
    if ( img != nil )
    {
@@ -429,7 +429,7 @@ NSString *K_ITEM_STACKED_REF = @"ItemStackedFlag";
       XCTAssertTrue( stackedFlag->stacked,
                     @"Bad notification flag state for item 0" );
 
-   LynkeosStandardImageBuffer *img = [[_doc imageList] getImage];
+   LynkeosImageBuffer *img = [[_doc imageList] getImage];
    XCTAssertNotNil( img, @"No stacking result for item 0" );
    if ( img != nil )
    {
@@ -479,7 +479,7 @@ NSString *K_ITEM_STACKED_REF = @"ItemStackedFlag";
       XCTAssertTrue( stackedFlag->stacked,
                     @"Bad notification flag state for item 0" );
 
-   LynkeosStandardImageBuffer *img = [[_doc imageList] getImage];
+   LynkeosImageBuffer *img = [[_doc imageList] getImage];
    XCTAssertNotNil( img, @"No stacking result for item 0" );
    if ( img != nil )
    {
@@ -529,7 +529,7 @@ NSString *K_ITEM_STACKED_REF = @"ItemStackedFlag";
       XCTAssertTrue( stackedFlag->stacked,
                     @"Bad notification flag state for item 0" );
 
-   LynkeosStandardImageBuffer *img = [[_doc imageList] getImage];
+   LynkeosImageBuffer *img = [[_doc imageList] getImage];
    XCTAssertNotNil( img, @"No stacking result for item 0" );
    if ( img != nil )
    {
