@@ -3,7 +3,7 @@
 //  $Id$
 //
 //  Created by Jean-Etienne LAMIAUD on Fri Sep 19 2008.
-//  Copyright (c) 2008-2013. Jean-Etienne LAMIAUD
+//  Copyright (c) 2008-2020. Jean-Etienne LAMIAUD
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
 
 #include "processing_core.h"
 #include <LynkeosCore/LynkeosFourierBuffer.h>
-#include "LynkeosStandardImageBufferAdditions.h"
+#include "LynkeosImageBufferAdditions.h"
 
 @interface LynkeosFourierBufferTest : XCTestCase
 {
@@ -263,13 +263,13 @@ extern BOOL testInitialized;
       hasSIMD = NO;
 
    // Allocate our images
-   // two in LynkeosStandardImageBuffer objects
-   LynkeosStandardImageBuffer *image1 =
-                 [LynkeosStandardImageBuffer imageBufferWithNumberOfPlanes:1 
+   // two in LynkeosImageBuffer objects
+   LynkeosImageBuffer *image1 =
+                 [LynkeosImageBuffer imageBufferWithNumberOfPlanes:1 
                                                                      width:30
                                                                      height:20];
-   LynkeosStandardImageBuffer *image2 =
-   [LynkeosStandardImageBuffer imageBufferWithNumberOfPlanes:1 
+   LynkeosImageBuffer *image2 =
+   [LynkeosImageBuffer imageBufferWithNumberOfPlanes:1 
                                                        width:30
                                                       height:20];
 
@@ -338,9 +338,9 @@ extern BOOL testInitialized;
       hasSIMD = NO;
 
    // Allocate our images
-   // one in a LynkeosStandardImageBuffer object
-   LynkeosStandardImageBuffer *image =
-                  [LynkeosStandardImageBuffer imageBufferWithNumberOfPlanes:1 
+   // one in a LynkeosImageBuffer object
+   LynkeosImageBuffer *image =
+                  [LynkeosImageBuffer imageBufferWithNumberOfPlanes:1 
                                                                       width:30
                                                                      height:20];
 
@@ -403,13 +403,13 @@ extern BOOL testInitialized;
       hasSIMD = NO;
 
    // Allocate our images
-   // two in LynkeosStandardImageBuffer objects
-   LynkeosStandardImageBuffer *image1 =
-                  [LynkeosStandardImageBuffer imageBufferWithNumberOfPlanes:1 
+   // two in LynkeosImageBuffer objects
+   LynkeosImageBuffer *image1 =
+                  [LynkeosImageBuffer imageBufferWithNumberOfPlanes:1 
                                                                       width:30
                                                                      height:20];
-   LynkeosStandardImageBuffer *image2 =
-                  [LynkeosStandardImageBuffer imageBufferWithNumberOfPlanes:1 
+   LynkeosImageBuffer *image2 =
+                  [LynkeosImageBuffer imageBufferWithNumberOfPlanes:1 
                                                                       width:30
                                                                      height:20];
 
