@@ -3,7 +3,7 @@
 //  $Id$
 //
 //  Created by Jean-Etienne LAMIAUD on Fri Sep 29 2006.
-//  Copyright (c) 2006-2014. Jean-Etienne LAMIAUD
+//  Copyright (c) 2006-2020. Jean-Etienne LAMIAUD
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -28,8 +28,8 @@
 #include "LynkeosThreadConnection.h"
 #include "MyProcessingThread.h"
 #include "MyImageAligner.h"
-#include "LynkeosStandardImageBuffer.h"
-#include "LynkeosStandardImageBufferAdditions.h"
+#include "LynkeosImageBuffer.h"
+#include "LynkeosImageBufferAdditions.h"
 #include "MyDocument.h"
 
 const NSPoint K_IMG10_STARS[] =
@@ -96,7 +96,7 @@ NSString *K_ITEM_ALIGNED_REF = @"ItemAlignedFlag";
 // Fake reader
 @interface TestReader : NSObject <LynkeosImageFileReader>
 {
-   LynkeosStandardImageBuffer *_image;
+   LynkeosImageBuffer *_image;
 }
 @end
 
@@ -172,7 +172,7 @@ NSString *K_ITEM_ALIGNED_REF = @"ItemAlignedFlag";
 - (id) init
 {
    if ( (self = [super init]) != nil )
-      _image = [[LynkeosStandardImageBuffer imageBufferWithNumberOfPlanes:1 
+      _image = [[LynkeosImageBuffer imageBufferWithNumberOfPlanes:1 
                                                       width:60
                                                      height:60] retain];
 
