@@ -3,7 +3,7 @@
 //  $Id$
 //
 //  Created by Jean-Etienne LAMIAUD on Thu Sep 7 2006.
-//  Copyright (c) 2006-2014. Jean-Etienne LAMIAUD
+//  Copyright (c) 2006-2020. Jean-Etienne LAMIAUD
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 #import <XCTest/XCTest.h>
 
-#include "LynkeosStandardImageBufferAdditions.h"
+#include "LynkeosImageBufferAdditions.h"
 #include "MyPluginsController.h"
 #include "LynkeosFileReader.h"
 #include "MyImageListItem.h"
@@ -40,7 +40,7 @@ NSString *basePath = nil;
 // The reader that the item under test will use
 @interface TestReader : NSObject <LynkeosImageFileReader>
 {
-   LynkeosStandardImageBuffer *buf;
+   LynkeosImageBuffer *buf;
 }
 // Test specific method
 @end
@@ -73,7 +73,7 @@ NSString *basePath = nil;
    else
       NSAssert( NO, @"Inconsistent image kind" );
 
-   buf = [[LynkeosStandardImageBuffer imageBufferWithNumberOfPlanes:n
+   buf = [[LynkeosImageBuffer imageBufferWithNumberOfPlanes:n
                                                               width:w
                                                              height:h] retain];
 
@@ -171,7 +171,7 @@ NSString *basePath = nil;
                                              [NSURL URLWithString:@"1.tsturl"]];
 
    // Read a sample
-   LynkeosStandardImageBuffer *testBuf = nil;
+   LynkeosImageBuffer *testBuf = nil;
    [item getImageSample:&testBuf inRect:LynkeosMakeIntegerRect(10,5,10,10)];
 
    XCTAssertNotNil( testBuf, @"Test image not read" );
@@ -201,7 +201,7 @@ NSString *basePath = nil;
                                              [NSURL URLWithString:@"1.tsturl"]];
 
    // Read a sample enclosing the image
-   LynkeosStandardImageBuffer *testBuf = nil;
+   LynkeosImageBuffer *testBuf = nil;
    [item getImageSample:&testBuf inRect:LynkeosMakeIntegerRect(-5,-4,40,30)];
 
    XCTAssertNotNil( testBuf, @"Test image not read" );
@@ -252,7 +252,7 @@ NSString *basePath = nil;
          if ( ox == 0 && oy == 0 )
             continue;
 
-         LynkeosStandardImageBuffer *testBuf = nil;
+         LynkeosImageBuffer *testBuf = nil;
          [item getImageSample:&testBuf inRect:LynkeosMakeIntegerRect(ox,oy,40,30)];
 
          XCTAssertNotNil( testBuf, @"Test image not read" );
@@ -275,7 +275,7 @@ NSString *basePath = nil;
                                              [NSURL URLWithString:@"1.tsturl"]];
 
    // Read a sample
-   LynkeosStandardImageBuffer *testBuf = [LynkeosStandardImageBuffer imageBufferWithNumberOfPlanes:1
+   LynkeosImageBuffer *testBuf = [LynkeosImageBuffer imageBufferWithNumberOfPlanes:1
                                                                    width:10
                                                                   height:10];
    [item getImageSample:&testBuf inRect:LynkeosMakeIntegerRect(10,5,10,10)];
@@ -301,10 +301,10 @@ NSString *basePath = nil;
    MyImageListItem *item = [MyImageListItem imageListItemWithURL:
                                              [NSURL URLWithString:@"1.tsturl"]];
    // And calibration frames
-   LynkeosStandardImageBuffer *dark = [LynkeosStandardImageBuffer imageBufferWithNumberOfPlanes:3
+   LynkeosImageBuffer *dark = [LynkeosImageBuffer imageBufferWithNumberOfPlanes:3
                                                                 width:31
                                                                height:19];
-   LynkeosStandardImageBuffer *flat = [LynkeosStandardImageBuffer imageBufferWithNumberOfPlanes:3
+   LynkeosImageBuffer *flat = [LynkeosImageBuffer imageBufferWithNumberOfPlanes:3
                                                                 width:31
                                                                height:19];
    u_short x, y;
@@ -338,7 +338,7 @@ NSString *basePath = nil;
                   forProcessing:nil];
 
    // Read a sample
-   LynkeosStandardImageBuffer *testBuf = nil;
+   LynkeosImageBuffer *testBuf = nil;
    [item getImageSample:&testBuf inRect:LynkeosMakeIntegerRect(10,5,10,10)];
 
    XCTAssertNotNil( testBuf, @"Test image not read" );
@@ -366,7 +366,7 @@ NSString *basePath = nil;
    MyImageListItem *item = [MyImageListItem imageListItemWithURL:
                                              [NSURL URLWithString:@"1.tsturl"]];
    // And an image
-   LynkeosStandardImageBuffer *image = [LynkeosStandardImageBuffer imageBufferWithNumberOfPlanes:3
+   LynkeosImageBuffer *image = [LynkeosImageBuffer imageBufferWithNumberOfPlanes:3
                                                                  width:31
                                                                 height:19];
    u_short x, y;
@@ -386,7 +386,7 @@ NSString *basePath = nil;
    [item setImage:image];
 
    // Read a sample
-   LynkeosStandardImageBuffer *testBuf = nil;
+   LynkeosImageBuffer *testBuf = nil;
    [item getImageSample:&testBuf inRect:LynkeosMakeIntegerRect(10,5,10,10)];
 
    XCTAssertNotNil( testBuf, @"Test image not read" );
@@ -441,9 +441,9 @@ NSString *basePath = nil;
    MyImageListItem *item
       = [[[MyImageListItem alloc] initWithURL:[NSURL URLWithString:@"2.tsturl"]]
          autorelease];
-   LynkeosStandardImageBuffer *image1 = nil;
-   LynkeosStandardImageBuffer *image2
-      = [LynkeosStandardImageBuffer imageBufferWithNumberOfPlanes:1
+   LynkeosImageBuffer *image1 = nil;
+   LynkeosImageBuffer *image2
+      = [LynkeosImageBuffer imageBufferWithNumberOfPlanes:1
                                                        width:r.size.width
                                                       height:r.size.height];
 
@@ -490,9 +490,9 @@ NSString *basePath = nil;
    MyImageListItem *item
    = [[[MyImageListItem alloc] initWithURL:[NSURL URLWithString:@"2.tsturl"]]
       autorelease];
-   LynkeosStandardImageBuffer *image1 = nil;
-   LynkeosStandardImageBuffer *image2
-   = [LynkeosStandardImageBuffer imageBufferWithNumberOfPlanes:1
+   LynkeosImageBuffer *image1 = nil;
+   LynkeosImageBuffer *image2
+   = [LynkeosImageBuffer imageBufferWithNumberOfPlanes:1
                                                          width:r.size.width
                                                         height:r.size.height];
 
@@ -542,9 +542,9 @@ NSString *basePath = nil;
    MyImageListItem *item
       = [[[MyImageListItem alloc] initWithURL:[NSURL URLWithString:@"2.tsturl"]]
          autorelease];
-   LynkeosStandardImageBuffer *image1 = nil;
-   LynkeosStandardImageBuffer *image2
-      = [LynkeosStandardImageBuffer imageBufferWithNumberOfPlanes:1
+   LynkeosImageBuffer *image1 = nil;
+   LynkeosImageBuffer *image2
+      = [LynkeosImageBuffer imageBufferWithNumberOfPlanes:1
                                                             width:r.size.width
                                                           height:r.size.height];
 
